@@ -119,6 +119,10 @@ void Engine::clearCheatVars()
 
 bool Engine::compareLastKeyInputs()
 {
+	#if DEMO
+		return false;
+	#endif
+	
 	if (strstr(lastKeyEvents, "lockandload"))
 	{
 		cheats = true;
@@ -476,28 +480,28 @@ void Engine::getInput()
 				}
 				
 				if (event.jbutton.button == joypad.fire)
-					keyState[SDLK_LCTRL] = 1;
+					keyState[keyboard.fire] = 1;
 				else if (event.jbutton.button == joypad.jump)
-					keyState[SDLK_UP] = 1;
+					keyState[keyboard.jump] = 1;
 				else if (event.jbutton.button == joypad.jetpack)
-					keyState[SDLK_SPACE] = 1;
+					keyState[keyboard.jetpack] = 1;
 				else if (event.jbutton.button == joypad.map)
-					keyState[SDLK_TAB] = 1;
+					keyState[keyboard.map] = 1;
 				else if (event.jbutton.button == joypad.pause)
-					keyState[SDLK_p] = 1;
+					keyState[keyboard.pause] = 1;
 				break;
 
 			case SDL_JOYBUTTONUP:
 				if (event.jbutton.button == joypad.fire)
-					keyState[SDLK_LCTRL] = 0;
+					keyState[keyboard.fire] = 0;
 				else if (event.jbutton.button == joypad.jump)
-					keyState[SDLK_UP] = 0;
+					keyState[keyboard.jump] = 0;
 				else if (event.jbutton.button == joypad.jetpack)
-					keyState[SDLK_SPACE] = 0;
+					keyState[keyboard.jetpack] = 0;
 				else if (event.jbutton.button == joypad.map)
-					keyState[SDLK_TAB] = 0;
+					keyState[keyboard.map] = 0;
 				else if (event.jbutton.button == joypad.pause)
-					keyState[SDLK_p] = 0;
+					keyState[keyboard.pause] = 0;
 				break;
 
 			default:
@@ -632,13 +636,13 @@ bool Engine::unpack(char *filename, int fileType)
 
 		if (fileType == PAK_MUSIC)
 		{
-			sprintf(tempPath, "%s/music.mod", userHomeDirectory);
+			sprintf(tempPath, "%smusic.mod", userHomeDirectory);
 			fp = fopen(tempPath, "wb");
 		}
 
 		if (fileType == PAK_FONT)
 		{
-			sprintf(tempPath, "%s/font.ttf", userHomeDirectory);
+			sprintf(tempPath, "%sfont.ttf", userHomeDirectory);
 			fp = fopen(tempPath, "wb");
 		}
 
@@ -1097,59 +1101,41 @@ int Engine::processWidgets()
 }
 
 #if !UNIX
-
-/*
-You're probably looking at this function and thinking,
-bloody hell, that's crap! Yeah you're right, it is... but it works...
-*/
-
-char *strtok_r(char *in, char *delim, char **notUsed)
+char *strtok_r(char *s1, const char *s2, char **lasts)
 {
-	static int pos = 0;
-	static char *line;
-	static char rtn[50];
-	memset(rtn, ' ', 50);
-
-	if (in != NULL)
+	char *ret;
+	
+	if (s1 == NULL)
 	{
-		pos = 0;
-		line = in;
+		s1 = *lasts;
 	}
-
-	char *c = line;
-
-	for (int i = 0 ; i < pos ; i++)
+	
+	while (*s1 && strchr(s2, *s1))
 	{
-		*c++;
-		if (!*c)
-			return NULL;
+		++s1;
 	}
-
-	int index = 0;
-
-	while (true)
+	
+	if (*s1 == '\0')
 	{
-		if (*c != *delim)
-		{
-			rtn[index] = *c;
-		}
-
-		*c++;
-		pos++;
-		index++;
-
-		if (*c == *delim)
-		{
-			pos++;
-			rtn[index] = '\0';
-			return rtn;
-		}
-
-		if (!c)
-			return NULL;
+		return NULL;
 	}
+	
+	ret = s1;
+	
+	while(*s1 && !strchr(s2, *s1))
+	{
+		++s1;
+	}
+	
+	if(*s1)
+	{
+		*s1++ = '\0';
+	}
+	
+	*lasts = s1;
+	
+	return ret;
 }
-
 #endif
 
 /*
@@ -1176,7 +1162,7 @@ bool Engine::loadDefines()
 
 		if (!strstr(token, "/*"))
 		{
-			sscanf(token, "%*s %s %[^\n]", string[0], string[1]);
+			sscanf(token, "%*s %s %[^\n\r]", string[0], string[1]);
 			data = new Data();
 			data->set(string[0], string[1], 1, 1);
 			defineList.add(data);
