@@ -191,10 +191,12 @@ void Graphics::delay(int time)
 
 		engine->getInput();
 		
+		/*
 		if (engine->keyState[SDLK_ESCAPE])
 		{
 			break;
 		}
+		*/
 	}
 }
 
@@ -501,7 +503,7 @@ void Graphics::loadFont(int i, char *filename, int pixelSize)
 	
 	char tempPath[PATH_MAX];
 	
-	sprintf(tempPath, "%s/font.ttf", engine->userHomeDirectory);
+	sprintf(tempPath, "%sfont.ttf", engine->userHomeDirectory);
 
 	bool found = false;
 	int size = 0;
