@@ -84,6 +84,15 @@ void showInGameOptions()
 	{
 		engine.showWidget("quit", false);
 	}
+	
+	#if DEMO
+		engine.enableWidget("escape", false);
+		engine.enableWidget("restart", false);
+		
+		Widget *widget;
+		widget = engine.getWidgetByName("quit");
+		strcpy(widget->label, "Quit Game");
+	#endif
 
 	engine.flushInput();
 	engine.clearInput();
@@ -214,7 +223,11 @@ void showInGameOptions()
 
 		if ((quityes) || (trainyes))
 		{
+			#if !DEMO
 			game.setMissionOver(MIS_PLAYERQUIT);
+			#else
+			showDemoEnd();
+			#endif
 			break;
 		}
 		
@@ -283,12 +296,16 @@ int gameover()
 	audio.stopAmbiance();
 	
 	if (!engine.loadWidgets("data/gameOverWidgets"))
+	{
 		graphics.showErrorAndExit(ERR_FILE, "data/gameOverWidgets");
+	}
 
 	SDL_Surface *gameover = graphics.quickSprite("Game Over", graphics.loadImage("gfx/main/gameover.png"));
 
+	#if !DEMO
 	audio.loadGameOverMusic();
 	audio.playMusic();
+	#endif
 
 	engine.flushInput();
 	engine.clearInput();
@@ -355,6 +372,11 @@ int gameover()
 		audio.fadeMusic();
 		graphics.fadeToBlack();
 		map.clear();
+		
+		#if DEMO
+			showDemoEnd();
+		#endif
+		
 		return SECTION_TITLE;
 	}
 
@@ -834,6 +856,10 @@ int doGame()
 				
 				showMissionClear();
 				
+				#if DEMO
+				showDemoEnd();
+				#endif
+				
 				if (engine.practice)
 				{
 					return SECTION_TITLE;
