@@ -194,7 +194,7 @@ void loadLevelBrief(char *levelName)
 	{
 		if (collectData)
 		{
-			sscanf(line, "%[^\n]", briefLine);
+			sscanf(line, "%[^\n\r]", briefLine);
 
 			if (strcmp(briefLine, "@EOF@") == 0)
 				break;
